@@ -7,6 +7,8 @@
 //! It currently handles binNMUs only.
 
 use crate::architectures::Architecture;
+use crate::archive::{Suite, SuiteOrCodename};
+use crate::version::PackageVersion;
 use std::fmt::{Display, Formatter};
 use std::io::Write;
 use std::process::{Command, Stdio};
@@ -134,9 +136,9 @@ impl TryFrom<&str> for WBArchitecture {
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct SourceSpecifier<'a> {
     source: &'a str,
-    version: Option<&'a str>,
+    version: Option<&'a PackageVersion>,
     architectures: Vec<WBArchitecture>,
-    suite: Option<&'a str>,
+    suite: Option<&'a SuiteOrCodename>,
 }
 
 impl<'a> SourceSpecifier<'a> {
@@ -151,13 +153,13 @@ impl<'a> SourceSpecifier<'a> {
     }
 
     /// Specify version of the source package.
-    pub fn with_version(&mut self, version: &'a str) -> &mut Self {
+    pub fn with_version(&mut self, version: &'a PackageVersion) -> &mut Self {
         self.version = Some(version);
         self
     }
 
     /// Specify suite. If not set, `unstable` is used.
-    pub fn with_suite(&mut self, suite: &'a str) -> &mut Self {
+    pub fn with_suite(&mut self, suite: &'a SuiteOrCodename) -> &mut Self {
         self.suite = Some(suite);
         self
     }
@@ -199,7 +201,7 @@ impl<'a> Display for SourceSpecifier<'a> {
             if let Some(suite) = self.suite {
                 suite
             } else {
-                "unstable"
+                &SuiteOrCodename::Suite(Suite::Unstable)
             },
         )
     }
@@ -369,6 +371,9 @@ mod test {
         BinNMU, BuildPriority, DepWait, SourceSpecifier, WBArchitecture, WBCommandBuilder,
     };
     use crate::architectures::Architecture;
+    use crate::archive::{Suite, SuiteOrCodename};
+
+    const TESTING: SuiteOrCodename = SuiteOrCodename::Suite(Suite::Testing(None));
 
     #[test]
     fn arch_from_str() {
@@ -410,7 +415,7 @@ mod test {
         );
         assert_eq!(
             BinNMU::new(
-                SourceSpecifier::new("zathura").with_version("2.3.4"),
+                SourceSpecifier::new("zathura").with_version(&"2.3.4".try_into().unwrap()),
                 "Rebuild on buildd"
             )
             .unwrap()
@@ -433,7 +438,7 @@ mod test {
         );
         assert_eq!(
             BinNMU::new(
-                SourceSpecifier::new("zathura").with_suite("testing"),
+                SourceSpecifier::new("zathura").with_suite(&TESTING),
                 "Rebuild on buildd"
             )
             .unwrap()
@@ -485,10 +490,13 @@ mod test {
             "bp 10 zathura . ANY . unstable"
         );
         assert_eq!(
-            BuildPriority::new(SourceSpecifier::new("zathura").with_version("2.3.4"), 10)
-                .unwrap()
-                .build()
-                .to_string(),
+            BuildPriority::new(
+                SourceSpecifier::new("zathura").with_version(&"2.3.4".try_into().unwrap()),
+                10
+            )
+            .unwrap()
+            .build()
+            .to_string(),
             "bp 10 zathura_2.3.4 . ANY . unstable"
         );
         assert_eq!(
@@ -505,7 +513,7 @@ mod test {
             "bp 10 zathura . ANY -i386 . unstable"
         );
         assert_eq!(
-            BuildPriority::new(SourceSpecifier::new("zathura").with_suite("testing"), 10)
+            BuildPriority::new(SourceSpecifier::new("zathura").with_suite(&TESTING), 10)
                 .unwrap()
                 .build()
                 .to_string(),
@@ -524,7 +532,7 @@ mod test {
         );
         assert_eq!(
             DepWait::new(
-                SourceSpecifier::new("zathura").with_version("2.3.4"),
+                SourceSpecifier::new("zathura").with_version(&"2.3.4".try_into().unwrap()),
                 "libgirara-dev"
             )
             .unwrap()
@@ -547,7 +555,7 @@ mod test {
         );
         assert_eq!(
             DepWait::new(
-                SourceSpecifier::new("zathura").with_suite("testing"),
+                SourceSpecifier::new("zathura").with_suite(&TESTING),
                 "libgirara-dev"
             )
             .unwrap()
